ACPExtensionEvent class

The ACPExtensionEvent class contains the event that is used by the internal Event Hub.

Constructors

ACPExtensionEvent(Map data)
ACPExtensionEvent.createEvent(String eventName, String eventType, String eventSource, Map eventData)

Properties

data ↔ Map
getter/setter pair
eventData → Map
The event data for this event.
no setter
eventName → String?
The name of this event.
no setter
eventSource → String?
The source of this event.
no setter
eventType → String?
The type of this event.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited